@@ -5,7 +5,7 @@
 */
 
 #include "addresseelineeditakonadi.h"
-#include <AkonadiCore/Session>
+#include <Akonadi/Session>
 
 using namespace PimCommon;
 
