@@ -2,7 +2,7 @@
   This file is part of libkdepim.
 
   SPDX-FileCopyrightText: 2006 Christian Schaarschmidt <schaarsc@gmx.de>
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -33,16 +33,15 @@ QString KMailCompletion::makeCompletion(const QString &string)
         const QString firstMatch(match);
         while (match.indexOf(QRegExp(QLatin1String("(@)|(<.*>)"))) == -1) {
             /* local email do not require @domain part, if match is an address we'll
-            * find last+first <match> in m_keyMap and we'll know that match is
-            * already a valid email.
-            *
-            * Distribution list do not have last+first <match> entry, they will be
-            * in mailAddr
-            */
-            const QStringList &mailAddr = m_keyMap[ match ]; //get all mailAddr for this keyword
+             * find last+first <match> in m_keyMap and we'll know that match is
+             * already a valid email.
+             *
+             * Distribution list do not have last+first <match> entry, they will be
+             * in mailAddr
+             */
+            const QStringList &mailAddr = m_keyMap[match]; // get all mailAddr for this keyword
             bool isEmail = false;
-            for (QStringList::ConstIterator sit(mailAddr.begin()), sEnd(mailAddr.end());
-                 sit != sEnd; ++sit) {
+            for (QStringList::ConstIterator sit(mailAddr.begin()), sEnd(mailAddr.end()); sit != sEnd; ++sit) {
                 if ((*sit).indexOf(QLatin1Char('<') + match + QLatin1Char('>')) != -1 || (*sit) == match) {
                     isEmail = true;
                     break;
@@ -69,11 +68,11 @@ void KMailCompletion::addItemWithKeys(const QString &email, int weight, const QS
     Q_ASSERT(keyWords != nullptr);
     QStringList::ConstIterator end = keyWords->constEnd();
     for (QStringList::ConstIterator it(keyWords->constBegin()); it != end; ++it) {
-        QStringList &emailList = m_keyMap[(*it)];  //lookup email-list for given keyword
-        if (!emailList.contains(email)) {       //add email if not there
+        QStringList &emailList = m_keyMap[(*it)]; // lookup email-list for given keyword
+        if (!emailList.contains(email)) { // add email if not there
             emailList.append(email);
         }
-        addItem((*it), weight);                     //inform KCompletion about keyword
+        addItem((*it), weight); // inform KCompletion about keyword
     }
 }
 
@@ -84,16 +83,14 @@ void KMailCompletion::postProcessMatches(QStringList *pMatches) const
         return;
     }
 
-    //KCompletion has found the keywords for us, we can now map them to mail-addr
-    QSet< QString > mailAddrDistinct;
-    for (QStringList::ConstIterator sit(pMatches->begin()), sEnd(pMatches->end());
-         sit != sEnd; ++sit) {
-        const QStringList &mailAddr = m_keyMap[(*sit) ];  //get all mailAddr for this keyword
-        for (QStringList::ConstIterator sit(mailAddr.begin()), sEnd(mailAddr.end());
-             sit != sEnd; ++sit) {
-            mailAddrDistinct.insert(*sit);    //store mailAddr, QSet will make them unique
+    // KCompletion has found the keywords for us, we can now map them to mail-addr
+    QSet<QString> mailAddrDistinct;
+    for (QStringList::ConstIterator sit(pMatches->begin()), sEnd(pMatches->end()); sit != sEnd; ++sit) {
+        const QStringList &mailAddr = m_keyMap[(*sit)]; // get all mailAddr for this keyword
+        for (QStringList::ConstIterator sit(mailAddr.begin()), sEnd(mailAddr.end()); sit != sEnd; ++sit) {
+            mailAddrDistinct.insert(*sit); // store mailAddr, QSet will make them unique
         }
     }
-    pMatches->clear();                        //delete keywords
-    (*pMatches) += mailAddrDistinct.values(); //add emailAddr
+    pMatches->clear(); // delete keywords
+    (*pMatches) += mailAddrDistinct.values(); // add emailAddr
 }
