@@ -12,8 +12,8 @@
 #include <KLDAP/LdapClient>
 #include <KLDAP/LdapClientSearch>
 
-#include <kcontacts/addressee.h>
-#include <kcontacts/contactgroup.h>
+#include <KContacts/Addressee>
+#include <KContacts/ContactGroup>
 #include <kldap/ldapserver.h>
 
 #include <KConfigGroup>
@@ -65,7 +65,6 @@ CompletionOrderEditor::CompletionOrderEditor(KLDAP::LdapClientSearch *ldapSearch
 CompletionOrderEditor::~CompletionOrderEditor()
 {
     writeConfig();
-    delete d;
 }
 
 void CompletionOrderEditor::readConfig()
